@@ -292,9 +292,12 @@ void StaticPage::resetQuickPage() {
 
     ui->quickStaticLenTxt->setText("0");
     ui->quickStaticTxt->clear();
+    ui->quickStaticTxt->setEnabled(false);
     ui->quickScanCodesTxt->clear();
-    ui->quickInsertTabBtn->setEnabled(true);
-    ui->quickClearBtn->setEnabled(true);
+    ui->quickScanCodesTxt->setEnabled(false);
+    ui->quickInsertTabBtn->setEnabled(false);
+    ui->quickClearBtn->setEnabled(false);
+    ui->quickKeymapCmb->setCurrentIndex(0);
 
     ui->quickStopBtn->setEnabled(false);
     ui->quickResetBtn->setEnabled(false);
@@ -1108,3 +1111,24 @@ void StaticPage::setCurrentSlot(int slot) {
         ui->quickConfigSlot2Radio->setChecked(slot == 2);
     }
 }
+
+void StaticPage::on_quickKeymapCmb_currentIndexChanged(int index)
+{
+    // Reset these, independent of the chosen layout
+    ui->quickStaticLenTxt->setText("0");
+    ui->quickStaticTxt->clear();
+    ui->quickScanCodesTxt->clear();
+
+    if (index == 0) {
+        ui->quickStaticTxt->setEnabled(false);
+        ui->quickScanCodesTxt->setEnabled(false);
+        ui->quickInsertTabBtn->setEnabled(false);
+        ui->quickClearBtn->setEnabled(false);
+    }
+    else {
+        ui->quickStaticTxt->setEnabled(true);
+        ui->quickScanCodesTxt->setEnabled(true);
+        ui->quickInsertTabBtn->setEnabled(true);
+        ui->quickClearBtn->setEnabled(true);
+    }
+}
