@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2011-2013 Yubico AB.  All rights reserved.
+Copyright (C) 2011-2014 Yubico AB.  All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are
@@ -28,7 +28,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "yubikeyutil.h"
 #include <yubikey.h>
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
 #include "crandom.h"
 #endif
 
@@ -84,7 +84,7 @@ QString YubiKeyUtil::qstrHexEncode(const unsigned char *str, size_t strLen) {
     int rc = hexModhexEncode(result, &resultLen, str, strLen, false);
 
     if(rc > 0) {
-        qDebug("hex encoded string: -%s- (%lu)", result, sizeof(result));
+        qDebug() << "hex encoded string: " << QString(result) << sizeof(result);
         return QString::fromLocal8Bit(result);
     }
 
@@ -117,7 +117,7 @@ QString YubiKeyUtil::qstrModhexEncode(const unsigned char *str, size_t strLen) {
     int rc = hexModhexEncode(result, &resultLen, str, strLen, true);
 
     if(rc > 0) {
-        qDebug("modhex encoded string: -%s- (%lu)", result, sizeof(result));
+        qDebug() << "modhex encoded string: " << QString(result) << sizeof(result);
         return QString::fromLocal8Bit(result);
     }
 
@@ -150,9 +150,8 @@ void YubiKeyUtil::qstrDecDecode(unsigned char *result, size_t *resultLen,
 
     *resultLen = str.size() / 2;
 
-    unsigned char val = 0;
     for(size_t i = 0; i < *resultLen; i++) {
-        val = str.mid(i * 2, 2).toInt();
+        unsigned char val = str.mid(i * 2, 2).toInt();
         result[i] = ((val / 10) << 4) | (val % 10);
     }
 }
@@ -206,7 +205,7 @@ int YubiKeyUtil::generateRandom(unsigned char *result, size_t resultLen) {
 
     size_t bufLen = 0;
 
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
     CRandom random;
     random.getRand(buf, bufSize);
 
